@@ -14,59 +14,38 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import logging
+
+import attr
+
 from subiquitycore.utils import crypt_password
 
 
 log = logging.getLogger('subiquitycore.models.identity')
 
 
-class LocalUser(object):
-    def __init__(self, result):
-        self._realname = result.get('realname')
-        self._username = result.get('username')
-        self._password = result.get('password')
-        self._cpassword = result.get('confirm_password')
-        self._ssh_import_id = None
-        if 'ssh_import_id' in result:
-            self._ssh_import_id = result.get('ssh_import_id')
-
-    @property
-    def realname(self):
-        return self._realname
-
-    @property
-    def username(self):
-        return self._username
-
-    @property
-    def password(self):
-        return self._password
-
-    @property
-    def cpassword(self):
-        return self._cpassword
-
-    @property
-    def ssh_import_id(self):
-        return self._ssh_import_id
-
-    def __repr__(self):
-        return "%s <%s>" % (self._realname, self._username)
+@attr.s
+class User(object):
+    realname = attr.ib()
+    username = attr.ib()
+    password = attr.ib()
 
 
 class IdentityModel(object):
     """ Model representing user identity
     """
 
-    def __init__(self, opts):
-        self.opts = opts
+    def __init__(self):
         self._user = None
+        self._hostname = None
 
     def add_user(self, result):
-        if result:
-            self._user = LocalUser(result)
-        else:
-            self._user = None
+        result = result.copy()
+        self._hostname = result.pop('hostname')
+        self._user = User(**result)
+
+    @property
+    def hostname(self):
+        return self._hostname
 
     @property
     def user(self):
@@ -76,4 +55,4 @@ class IdentityModel(object):
         return crypt_password(passinput)
 
     def __repr__(self):
-        return "<LocalUser: {}>".format(self.user)
+        return "<LocalUser: {} {}>".format(self.user, self.hostname)
