@@ -13,9 +13,15 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from urwid import WidgetWrap, Pile, Text, ProgressBar
+from urwid import (
+    Text,
+    ProgressBar,
+    )
+from subiquitycore.ui.container import (
+    Pile,
+    WidgetWrap,
+    )
 from subiquitycore.ui.utils import Padding, Color
-from subiquitycore.ui.lists import SimpleList
 
 
 class Header(WidgetWrap):
@@ -27,17 +33,19 @@ class Header(WidgetWrap):
     :returns: Header()
     """
 
-    def __init__(self, title=None, excerpt=None):
-        widgets = [Text("")]
-        if title is not None:
-            widgets.append(
-                Padding.center_79(Color.body(Text(title))))
-            widgets.append(Text(""))
-        if excerpt is not None:
-            widgets.append(
-                Padding.center_79(Color.body(Text(excerpt))))
-            widgets.append(Text(""))
-        super().__init__(Pile(widgets))
+    def __init__(self, title):
+        if isinstance(title, str):
+            title = Text(title)
+        title = Padding.center_79(title, min_width=76)
+        super().__init__(Color.frame_header(
+                Pile(
+                    [Text(""), title, Text("")])))
+
+
+class StepsProgressBar(ProgressBar):
+
+    def get_text(self):
+        return "{} / {}".format(self.current, self.done)
 
 
 class Footer(WidgetWrap):
@@ -47,24 +55,17 @@ class Footer(WidgetWrap):
 
     """
 
-    def __init__(self, message="", completion=0):
-        message_widget = Padding.center_79(Color.body(Text(message)))
+    def __init__(self, message, current, complete):
+        if isinstance(message, str):
+            message = Text(message)
+        message = Padding.center_79(message, min_width=76)
         progress_bar = Padding.center_60(
-            ProgressBar(normal='progress_incomplete',
-                        complete='progress_complete',
-                        current=completion, done=100))
+            StepsProgressBar(normal='progress_incomplete',
+                             complete='progress_complete',
+                             current=current, done=complete))
         status = [
+            progress_bar,
             Padding.line_break(""),
-            message_widget,
+            message,
         ]
-        if completion > 0:
-            status.insert(0, progress_bar)
-        super().__init__(Pile(status))
-
-
-class Body(WidgetWrap):
-    """ Body widget
-    """
-
-    def __init__(self):
-        super().__init__(SimpleList([Text("")]))
+        super().__init__(Color.frame_footer(Pile(status)))
